<?php

if( ! defined( 'ABSPATH' ) ) {
    return;
}

/**
 * Add Metabox to display user information
 * @return void
 */
function giveasap_add_metabox_for_users() {
    add_meta_box( 'giveasap_users', __( 'Users', 'giveasap' ), 'giveasap_metabox_users', array( 'giveasap' ), 'side', 'high' );
    add_meta_box( 'giveasap_ideas', __( 'Have an Idea?', 'giveasap' ), 'giveasap_metabox_ideas', array( 'giveasap' ), 'side', 'low' );
}
add_action( 'add_meta_boxes', 'giveasap_add_metabox_for_users' );

 

/**
 * Rendering users and user actions in metabox
 * @param  object $post Post object
 * @return void       
 */
function giveasap_metabox_users( $post ){
    $post_id = $post->ID;
    $registered_users = giveasap_get_entries_for( $post_id );
    $count_users = 0;
    if( $registered_users && is_array( $registered_users ) ){
        $count_users = count( $registered_users );
    }
    ?>
    <p>
        <?php _e( 'Registered users:', 'giveasap' ); ?> <strong><?php echo $count_users; ?></strong>
        <?php if( $count_users > 0 ) { ?>
             <a href="<?php echo admin_url( 'admin.php?page=giveasap-users&id=' . $post->ID ); ?>"  class="button  button-small right"><?php _e( 'List Users', 'giveasap' ); ?></a>
       
        <?php } ?>
    </p>
    <?php 
    
    $winners = giveasap_get_winners( $post_id );
    $all_winners_notified = true;
    if( $winners ) {
        ?>
        <div class="giveasap_winners">
            <strong><?php _e( 'Winners', 'giveasap' ); ?></strong>
            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <th><?php _e( 'Email', 'giveasap' ); ?></th>
                        <th style="width: 60px;"><?php _e( 'Notified', 'giveasap' ); ?></th>
                    </tr>
                </thead>
                <tbody>
                <?php
                    foreach ( $winners as $winner ) {
                        if( 'no' === $winner['emailed'] ) {
                            $all_winners_notified = false;
                        }

                        $subscriber_id = isset( $winner['id'] ) ? absint( $winner['id'] ) : 0;
                        if ( ! $subscriber_id ) {
                            $user = giveasap_get_user_by_email( $winner['email'], $post_id );
                            $subscriber_id = $user->id;
                        }
                        echo '<tr><td><a href="' . admin_url( 'edit.php?post_type=giveasap&page=giveasap-users&user=' . $subscriber_id . '&action=view') . '">' . esc_html( $winner['email'] ) . '</a></td><td>' . strtoupper( $winner['emailed'] ) . '</td></tr>';
                    }
                ?>
                </tbody>
            </table>
            <button type="submit" name="giveasap_export_winners" id="export_winners" class="button"><?php _e( 'Export Winner(s) CSV', 'giveasap' ); ?></button>
        </div>
        <br/>
        <?php
    } 

    if( 'giveasap_ended' == $post->post_status && $count_users > 0 ) {
        ?>
        <button type="submit" name="giveasap_select" value="<?php echo esc_attr( $post_id ); ?>" id="notify" class="button button-primary button-large"><?php _e( 'Select Winner(s)', 'giveasap' ); ?></button>
        <?php
    }

    if( 'giveasap_winners' == $post->post_status && $count_users > 0 ) {
        ?>
        <p><button type="submit" name="giveasap_select" value="<?php echo esc_attr( $post_id ); ?>" id="sg-reselect-winners" class="button button-primary button-large"><?php _e( 'Reselect Winner(s)', 'giveasap' ); ?></button></p>
        <button type="submit" name="giveasap_notify" id="notify" class="button button-primary button-large"><?php _e( 'Notify Winner(s)', 'giveasap' ); ?></button>
        <?php
    }

    if( 'giveasap_notified' == $post->post_status && ! $all_winners_notified ) {
        ?>
        <button type="submit" name="giveasap_notify" id="notify" class="button button-primary button-large"><?php _e( 'Notify Winner(s)', 'giveasap' ); ?></button>
        <?php
    }
    ?>

    <?php if( $count_users > 0 ) { ?>
        <button type="submit" name="giveasap_export" id="export" class="button  button-large"><?php _e( 'Export CSV', 'giveasap' ); ?></button>
    <?php 
    }   

    ?>
    <hr/>
    <p><strong><?php _e( 'Have you checked out our integrations section? You can enhance your experience on new giveaways!', 'giveasap' ); ?></strong></p>
    <a target="_blank" href="<?php echo admin_url('edit.php?post_type=giveasap&page=giveasap_integrations'); ?>" class="button button-default"><?php _e( 'Go to Integrations', 'giveasap' ); ?></a>
    <?php
}

add_action( 'admin_init', 'giveasap_admin_end_giveaway', 99 );

/**
 * End Giveaway on Request
 *
 * @since  2.6.2 
 *
 * @return void 
 */
function giveasap_admin_end_giveaway() {
    if( isset( $_REQUEST['giveasap_end'] ) ) {
 
        $post_id = isset( $_REQUEST['post_ID'] ) ? $_REQUEST['post_ID'] : absint( $_REQUEST['giveasap_end'] );

        if( ! $post_id ) { $post_id = 0; }

        if( $post_id == 0 ) {
            return false;
        }
        if( isset( $_GET['action'] ) ) {
            unset( $_GET['action'] );
        }
        if( isset( $_GET['message'] ) ) {
            unset( $_GET['message'] );
        }
        
        $set_status = giveasap_set_status( $post_id, 'giveasap', 'giveasap_ended' );
             
        wp_redirect( admin_url( 'post.php?post=' . $post_id .'&action=edit&message=20' ), '301' );
        exit();
        
    }
}


add_action( 'admin_init', 'giveasap_metabox_users_select_winner', 99 );

/**
 * Select winners
 * @return void 
 */
function giveasap_metabox_users_select_winner(){
    
    if( isset( $_REQUEST['giveasap_select'] ) ) {
 
        $post_id = isset( $_REQUEST['post_ID'] ) ? $_REQUEST['post_ID'] : absint( $_REQUEST['giveasap_select'] );

        if( ! $post_id ) { $post_id = 0; }

        if( $post_id == 0 ) {
            return false;
        }
        if( isset( $_GET['action'] ) ) {
            unset( $_GET['action'] );
        }
        if( isset( $_GET['message'] ) ) {
            unset( $_GET['message'] );
        }
        
        $selected = giveasap_select_winner( $post_id );

        if( $selected ) {

            $set_status = giveasap_set_status( $post_id, 'giveasap', 'giveasap_winners', 'giveasap_ended' );
             
            wp_redirect( admin_url( 'post.php?post=' . $post_id .'&action=edit&message=21' ), '301' );
            exit();
        }
        
    }
}

add_action( 'admin_init', 'giveasap_metabox_users_notify_winners', 99 );
function giveasap_metabox_users_notify_winners(){
    if( isset( $_REQUEST['giveasap_notify'] ) ) {
       
        $post_id = isset( $_REQUEST['post_ID'] ) ? $_REQUEST['post_ID'] : absint( $_REQUEST['giveasap_notify'] );

        if( ! $post_id ) { $post_id = 0; }

        if( $post_id == 0 ) {
            return false;
        }
        if( isset( $_GET['action'] ) ) {
            unset( $_GET['action'] );
        }
        if( isset( $_GET['message'] ) ) {
            unset( $_GET['message'] );
        }

        $winners = giveasap_get_winners( $post_id );

        giveasap_notify_winners( $winners, $post_id );

        giveasap_set_status( $post_id, 'giveasap', 'giveasap_notified', 'giveasap_winners' );
        wp_redirect( admin_url( 'post.php?post=' . $post_id .'&action=edit&message=22' ), '301' );
        exit();
    }
}

add_action( 'admin_init', 'giveasap_metabox_users_export', 99 );
function giveasap_metabox_users_export(){
    if( isset( $_REQUEST['giveasap_export'] ) ) {
        $post_id = isset( $_REQUEST['post_ID'] ) ? $_REQUEST['post_ID'] : absint( $_REQUEST['giveasap_export'] );

        if( ! $post_id ) { $post_id = 0; }
        
        if( $post_id == 0 ) {
            return false;
        }

        if( isset( $_GET['action'] ) ) {
            unset( $_GET['action'] );
        }
        if( isset( $_GET['message'] ) ) {
            unset( $_GET['message'] );
        }

        $users = giveasap_get_entries_for( $post_id );

        if( is_array( $users ) && count( $users ) > 0 ) {
            $post = get_post( $post_id );
            header('Content-Type: text/csv; charset=utf-8');
            header('Content-Disposition: attachment; filename=giveasap_' . $post->post_name . '_users.csv');

            // create a file pointer connected to the output stream
            $output   = fopen('php://output', 'w');
            $fields   = sg_get_form_fields( $post_id );
            $headers  = array( __( 'Email Address', 'giveasap' ) );
            foreach ( $fields as $field_slug => $field ) {
	            if ( 'user_email' === $field_slug ) {
		            continue;
	            }
                if ( ! $field['label'] ) { continue; }
                $headers[] = $field['label'];
            }

            // output the column headings
            fputcsv( $output, $headers );
            foreach ( $users as $user ) {
                if( $user->email == '' ) {
                    continue;
                }

	            $meta = giveasap_get_meta( $user->id );
                $row  = array( $user->email );

	            foreach ( $fields as $field_slug => $field ) {
		            if ( ! $field['label'] ) {
			            continue;
		            }

		            if ( 'user_email' === $field_slug ) {
		                continue;
                    }
		            $headers[] = $field['label'];

		            if ( 'user_name' === $field_slug ) {
			            $value = isset( $meta[ '_' . $field_slug ] ) ? $meta[ '_' . $field_slug ] : '';

			            if ( ! $value ) {
				            $value = isset( $meta[ '_name' ] ) ? $meta[ '_name' ] : '';
			            }
		            } else {
			            $value = isset( $meta[ '_' . $field_slug ] ) ? $meta[ '_' . $field_slug ] : '';
                    }

		            if ( $value && is_array( $value ) ) {
			            $field_value = implode( ', ', $value );
		            } else {
			            $field_value = $value;
		            }

		            $row[] = $field_value;
	            }
                fputcsv( $output,  $row );
            }
            exit();
        }
    }
}


add_action( 'admin_init', 'giveasap_metabox_users_export_winners', 99 );
function giveasap_metabox_users_export_winners(){
	if( isset( $_REQUEST['giveasap_export_winners'] ) ) {
		$post_id = isset( $_REQUEST['post_ID'] ) ? $_REQUEST['post_ID'] : absint( $_REQUEST['giveasap_export_winners'] );

		if( ! $post_id ) { $post_id = 0; }

		if( $post_id == 0 ) {
			return false;
		}

		if( isset( $_GET['action'] ) ) {
			unset( $_GET['action'] );
		}
		if( isset( $_GET['message'] ) ) {
			unset( $_GET['message'] );
		}

		$users = giveasap_get_winners( $post_id );

		if( is_array( $users ) && count( $users ) > 0 ) {
			$post = get_post( $post_id );
			header('Content-Type: text/csv; charset=utf-8');
			header('Content-Disposition: attachment; filename=giveasap_' . $post->post_name . '_winners.csv');

			// create a file pointer connected to the output stream
			$output   = fopen('php://output', 'w');
			$fields   = sg_get_form_fields( $post_id );
			$headers  = array( __( 'Email Address', 'giveasap' ) );
			foreach ( $fields as $field_slug => $field ) {
				if ( 'user_email' === $field_slug ) {
					continue;
				}
				if ( ! $field['label'] ) { continue; }
				$headers[] = $field['label'];
			}

			// output the column headings
			fputcsv( $output, $headers );
			foreach ( $users as $winner ) {
				$subscriber_id = isset( $winner['id'] ) ? absint( $winner['id'] ) : 0;
				$user          = giveasap_get_user_by_email( $winner['email'], $post_id );

				if( $user->email == '' ) {
					continue;
				}

				$meta = giveasap_get_meta( $user->id );
				$row  = array( $user->email );

				foreach ( $fields as $field_slug => $field ) {
					if ( ! $field['label'] ) {
						continue;
					}

					if ( 'user_email' === $field_slug ) {
						continue;
					}
					$headers[] = $field['label'];

					if ( 'user_name' === $field_slug ) {
						$value = isset( $meta[ '_' . $field_slug ] ) ? $meta[ '_' . $field_slug ] : '';

						if ( ! $value ) {
							$value = isset( $meta[ '_name' ] ) ? $meta[ '_name' ] : '';
						}
					} else {
						$value = isset( $meta[ '_' . $field_slug ] ) ? $meta[ '_' . $field_slug ] : '';
					}

					if ( $value && is_array( $value ) ) {
						$field_value = implode( ', ', $value );
					} else {
						$field_value = $value;
					}

					$row[] = $field_value;
				}
				fputcsv( $output,  $row );
			}
			exit();
		}
	}
}

/**
 * Display The Giveaway Idea metabox
 * @param  WP_Post $post 
 * @return void       
 */
function giveasap_metabox_ideas( $post ) {
    ?>
    <p>If you have an idea on a feature you would like to see, feel free to write that idea down on our site.</p>
    <a href="http://www.wpsimplegiveaways.com/ideas" target="_blank" class="button button-secondary"><strong>Share your Idea</strong></a>
    <?php
}

add_action( 'admin_init', 'sg_process_action_clone' );

/**
 * Processing the Clone Giveaway action.
 *
 * @since 2.17.0
 */
function sg_process_action_clone() {
    $giveaway_id = isset( $_GET['sg_clone_giveaway'] ) ? absint( $_GET['sg_clone_giveaway'] ) : 0;

    if ( ! $giveaway_id ) {
        return;
    }

    $giveaway = sg_get_giveaway( $giveaway_id );
    $post     = (array) $giveaway->get_post();

    if ( ! $post ) {
        return;
    }

    $new_giveaway = array(
        'post_title'   => $post['post_title'],
        'post_content' => $post['post_content'],
        'post_type'    => 'giveasap',
        'post_status'  => 'draft'
    );
    $new_id = wp_insert_post( wp_slash( $new_giveaway ) );

    if ( ! $new_id || is_wp_error( $new_id ) ) {
        return;
    }

    $post_meta = get_post_meta( $giveaway_id );

    $ignored_meta = apply_filters(
            'sg_clone_giveaway_ignored_meta',
            array(
                'giveasap_winners',
                'end_time',
                '_edit_last',
                '_edit_lock',
            )
    );

    foreach ( $post_meta as $meta_key => $meta_value ) {
        if ( in_array( $meta_key, $ignored_meta, true ) ) {
            continue;
        }
        foreach ( $meta_value as $value ) {
	        add_post_meta( $new_id, $meta_key, maybe_unserialize( $value ) );
        }
    }

	wp_redirect( admin_url( 'edit.php?post_type=giveasap&message=23' ), '301' );
	exit();
}