<?php
/**
 * All functions related to extra actions
 */

if ( ! defined( 'ABSPATH' ) ) {
	return;
}

add_action( 'wp_ajax_sg_extra_action_check', 'sg_extra_action_check_ajax' );
add_action( 'wp_ajax_nopriv_sg_extra_action_check', 'sg_extra_action_check_ajax' );

/**
 * Checking for Action when clicked.
 */
function sg_extra_action_check_ajax() {
    check_ajax_referer( 'giveaway', 'nonce', true );

    $data = false;
    parse_str( isset( $_REQUEST['data'] ) ? $_REQUEST['data'] : '', $data );

    $action = isset( $data['extra_action'] ) ? $data['extra_action'] : false;

    if ( ! $action ) {
        wp_send_json_error( __( 'No Action selected', 'giveasap' ) );
        wp_die();
    }

    $instance_id = isset( $data['instance'] ) ? absint( $data['instance'] ) : 0;

    if ( ! $instance_id ) {
	    wp_send_json_error( __( 'This action is invalid. No instance.', 'giveasap' ) );
	    wp_die();
    }

	$subscriber_id = isset( $data['subscriber_id'] ) ? absint( $data['subscriber_id'] ) : 0;

	if ( ! $subscriber_id ) {
		wp_send_json_error( __( 'No subscriber found.', 'giveasap' ) );
		wp_die();
	}

	$actions = sg_get_registered_actions();

	$action_class = isset( $actions[ $action ] ) ? $actions[ $action ] : false;

	if ( ! $action_class ) {
		wp_send_json_error( __( 'Action could not be checked.', 'giveasap' ) );
		wp_die();
    }

    if ( ! class_exists( $action_class ) ) {
	    wp_send_json_error( __( 'Action is not available anymore.', 'giveasap' ) );
	    wp_die();
    }

    $action_object = new $action_class();
    $validation    = $action_object->validate( $instance_id, $subscriber_id );

	if ( is_wp_error( $validation ) ) {
		wp_send_json_error( $validation->get_error_message() );
		wp_die();
    }

    wp_send_json_success( $validation );
    exit;
}

add_action( 'wp_ajax_sg_extra_action_complete', 'sg_extra_action_complete_ajax' );
add_action( 'wp_ajax_nopriv_sg_extra_action_complete', 'sg_extra_action_complete_ajax' );

/**
 * Completing the Action when clicked.
 */
function sg_extra_action_complete_ajax() {
	check_ajax_referer( 'giveaway', 'nonce', true );

	$data = false;
	parse_str( isset( $_REQUEST['data'] ) ? $_REQUEST['data'] : array(), $data );

	$action = isset( $data['extra_action'] ) ? $data['extra_action'] : false;

	if ( ! $action ) {
		wp_send_json_error( __( 'No Action selected', 'giveasap' ) );
		wp_die();
	}

	$instance_id = isset( $data['instance'] ) ? absint( $data['instance'] ) : 0;

	if ( ! $instance_id ) {
		wp_send_json_error( __( 'This action is invalid. No instance.', 'giveasap' ) );
		wp_die();
	}

	$subscriber_id = isset( $data['subscriber_id'] ) ? absint( $data['subscriber_id'] ) : 0;

	if ( ! $subscriber_id ) {
		wp_send_json_error( __( 'No subscriber found.', 'giveasap' ) );
		wp_die();
	}

	$actions = sg_get_registered_actions();

	$action_class = isset( $actions[ $action ] ) ? $actions[ $action ] : false;

	if ( ! $action_class ) {
		wp_send_json_error( __( 'Action could not be completed.', 'giveasap' ) );
		wp_die();
	}

	if ( ! class_exists( $action_class ) ) {
		wp_send_json_error( __( 'Action is not available anymore.', 'giveasap' ) );
		wp_die();
	}

	$action_object = new $action_class();
	$complete      = $action_object->complete( $instance_id, $subscriber_id, $data );

	if ( is_wp_error( $complete ) ) {
		wp_send_json_error( $complete->get_error_message() );
		wp_die();
	}

	$subscriber = sg_get_subscriber( $subscriber_id );

	ob_start();
	$action_object->form_public_content();
	if ( $action_object->has_action_button() ) {
	    $action_object->action_button();
    }
	$html = ob_get_clean();

	$success_data = array(
        'html'          => $html,
        'complete_mark' => $action_object->complete_mark(),
        'entries'       => $subscriber->get_entries()
    );

	wp_send_json_success( $success_data );
	wp_die();
}

/**
 * Return all the registered actions.
 *
 * @return array
 */
function sg_get_registered_actions() {
   $actions = array(
       'subscribe'       => 'SG_Action_Subscribe',
       'referred'        => 'SG_Action_Referred',
       'visit'           => 'SG_Action_Visit',
       'facebook_visit'  => 'SG_Action_Premium_Dummy_Facebook_Visit',
       'twitter_visit'   => 'SG_Action_Premium_Dummy_Twitter_Visit',
       'instagram_visit' => 'SG_Action_Premium_Dummy_Instagram_Visit',
       'twitter_follow'  => 'SG_Action_Premium_Dummy_Twitter_Follow',
       'twitter_tweet'   => 'SG_Action_Premium_Dummy_Twitter_Tweet',
       'image'           => 'SG_Action_Image',
       'question'        => 'SG_Action_Premium_Dummy_Question',
       'secret_code'     => 'SG_Action_Premium_Dummy_Secret_Code',
   );

   return apply_filters( 'sg_registered_actions', $actions );
}

/**
 * Return the Action object.
 *
 * @param $slug
 *
 * @return boolean|SG_Extra_Action False if it does not exist.
 */
function sg_get_action_object( $slug ) {
    $actions = sg_get_registered_actions();

    if ( isset( $actions[ $slug ] ) ) {
        $class = $actions[ $slug ];
        if ( class_exists( $class ) ) {
            return new $class();
        }
    }

    return false;
}

/**
 * Return the categories for actions
 *
 * @return array
 */
function sg_get_actions_categories() {

    $categories = array(
        'general' => __( 'General', 'giveasap' ),
        'twitter' => __( 'Twitter', 'giveasap' ),
    );

    return apply_filters( 'sg_actions_categories', $categories );
}

/**
 * Get all the extra actions for the current giveaway.
 *
 * @param integer $giveaway_id Giveaway ID (Post ID).
 */
function sg_get_extra_actions( $giveaway_id ) {
	$extra = get_post_meta( $giveaway_id, 'giveasap_extra_entries', true );
	return isset( $extra['entries_actions'] ) ? $extra['entries_actions'] : array();
}

add_action( 'giveasap_the_form_end', 'sg_show_extra_actions', 20, 2 );

/**
 * Show extra actions on the form.
 * @param GiveASAP_Front $front
 * @param array $settings
 */
function sg_show_extra_actions( $front, $settings = array() ) {
	$giveaway_id = $front->get_giveaway_id();
	if ( ! $giveaway_id ) { return; }

	$actions = sg_get_extra_actions( $giveaway_id );
    $registered_actions = sg_get_registered_actions();

	if ( ! $actions ) { return; }

	?>
	<h3 class="giveasap-entries-title"><?php esc_html_e( 'Complete These Actions for Additional Entries', 'giveasap' ); ?></h3>
	<ul class="giveasap_extra_actions row">
		<?php

		foreach ( $actions as $index => $action ) {
		    $action_class = isset( $registered_actions[ $action['action'] ] ) ? $registered_actions[ $action['action'] ] : false;

		    if ( false === $action_class ) {
		        continue;
            }
			$action_object = new $action_class();
            $action_object->set_admin_data( $action );
		    $action_object->set_subscriber_id( $front->user->id );
		    echo '<li>';
		    $action_object->form_public();
		    echo '</li>';
		}
		?>
	</ul>
	<?php
}

/**
 * Creating a list item for each action.
 *
 * @deprecated 2.20.0 No longer used. Will be removed in future version.
 *
 * @param array  $action
 * @param integr $index
 * @param array $used_actions Array of used action indexes.
 */
function sg_display_extra_action_item( $action, $index, $used_actions ) {
	$class = 'giveasap_';
	$icon  = 'fal fa-link';
	$url   = $action['url'];
	$entries = '<span class="method-entry">+' . $action['entries'] . '</span>';
	$style = '';
	$bg_color = '#000';
	$txt_color = '#fff';

	if ( isset( $action['bg_color'] ) && $action['bg_color'] ) {
	    $bg_color = $action['bg_color'];
    }

	if ( isset( $action['txt_color'] ) && $action['txt_color'] ) {
		$txt_color = $action['txt_color'];
	}

	$style = 'background-color: ' . $bg_color . ';color: ' . $txt_color . ';';

	if ( 'link' === $action['type'] ) {
		$class = 'custom';
	} else {
		$class .= $action['social'];
		switch ( $action['social'] ) {
			case 'facebook':
				$icon = 'fab fa-facebook';
				break;
			case 'twitter':
				$icon = 'fab fa-twitter';
				$url  = 'https://twitter.com/' . $action['username'];
				break;
			case 'instagram':
				$icon = 'fab fa-instagram';
				$url  = 'https://instagram.com/' . $action['username'];
				$class = 'custom';
				break;
			case 'youtube':
				$icon = 'fab fa-youtube';
				$class = 'custom';
				break;
			default:
				break;
		}
	}

	if ( in_array( $index, $used_actions, true ) ) {
		$class .= ' sg-used-action';
		$entries = '<i class="fal fa-check-square method-entry"></i>';
	}

	?>
	<li class="sharing_method <?php echo esc_attr( $class ); ?>">
		<a data-action="<?php echo $index; ?>" target="_blank" href="<?php echo esc_attr( $url ); ?>" style="<?php echo esc_attr( $style ); ?>">
			<span class="<?php echo $icon; ?>"></span>
			<?php echo esc_html( $action['text'] ); ?>
			<?php echo $entries; ?>
		</a>
	</li>
	<?php
}

add_action( 'wp_ajax_sg_extra_action', 'sg_register_extra_action' );
add_action( 'wp_ajax_nopriv_sg_extra_action', 'sg_register_extra_action' );

/**
 * Register the extra action.
 *
 * @deprecated 2.20.0 No longer used. Will be removed in future version.
 */
function sg_register_extra_action() {
	$giveaway = isset( $_REQUEST['giveaway'] ) ? absint( $_REQUEST['giveaway'] ) : 0;

	if ( ! $giveaway ) {
		wp_send_json_error( __( 'No Giveaway provided for the Action.', 'giveasap' ) );
		wp_die();
	}

	$subscriber = isset( $_REQUEST['subscriber'] ) ? absint( $_REQUEST['subscriber'] ) : 0;

	if ( ! $subscriber ) {
		wp_send_json_error( __( 'No Subscriber provided for the Action.', 'giveasap' ) );
		wp_die();
	}

	$action = isset( $_REQUEST['index'] ) ? absint( $_REQUEST['index'] ) : 0;

	if ( ! is_numeric( $action ) ) {
		wp_send_json_error( __( 'No Action provided.', 'giveasap' ) );
		wp_die();
	}

	$user = giveasap_get_user_by_id( $subscriber, $giveaway );
	$entries = (int) $user->entries;

	if ( ! sg_is_extra_action_used( $subscriber, $action ) ) {

		$actions = sg_get_extra_actions( $giveaway );

		$current_action = isset( $actions[ $action ] ) ? $actions[ $action ] : array();

		$entries += absint( $current_action['entries'] );

		giveasap_update_user_entry( $subscriber, $entries );
		sg_set_extra_action_as_used( $subscriber, $action );
	}

	wp_send_json_success( array( 'entries' => $entries ) );
	wp_die();
}

/**
 * Set the extra action as used.
 *
 * @deprecated 2.20.0 No longer used. Will be removed in future version.
 *
 * @param integer $subscriber Subscriber ID
 * @param integer $index Action Index
 */
function sg_set_extra_action_as_used( $subscriber, $index ) {
	$used_actions = sg_get_used_extra_actions( $subscriber );

	if ( ! in_array( absint( $index ), $used_actions, true ) ) {
		$used_actions[] = $index;
	}

	giveasap_update_meta( $subscriber, '_used_extra_actions', $used_actions );
}

/**
 * Return if the current action was already used.
 *
 * @deprecated 2.20.0 No longer used. Will be removed in future version.
 *
 * @param integer $subscriber
 * @param integer $index
 *
 * @return boolean
 */
function sg_is_extra_action_used( $subscriber, $index ) {
	$used_actions = sg_get_used_extra_actions( $subscriber );

	if ( ! in_array( absint( $index ), $used_actions, true ) ) {
		return false;
	}

	return true;
}

/**
 * Return the used actions.
 *
 * @param $subscriber
 *
 * @deprecated 2.20.0 No longer used. Will be removed in future version.
 *
 * @return array|mixed
 */
function sg_get_used_extra_actions( $subscriber ) {
	$used_actions = giveasap_get_meta( $subscriber, '_used_extra_actions', true );

	if ( ! $used_actions ) {
		$used_actions = array();
	}

	return $used_actions;
}