<?php

/**
 * Shortcode functionality
 */

if( ! defined( 'ABSPATH' ) ) {
	return;
}

add_action( 'init', 'sg_register_all_shortcodes' );

/**
 * Register Shortcodes with appropriate functions.
 *
 * @since 2.17.0
 * @since 2.18.1 Renamed to sg_register_all_shortcodes due to SendGrid having the same function.
 */
function sg_register_all_shortcodes() {
	add_shortcode( 'giveaway', 'giveasap_shortcode' );
	add_shortcode( 'giveaway_winners', 'sg_show_winners_shortcode' );
	add_shortcode( 'giveaway_leaderboard', 'sg_giveaway_leaderboard_shortcode' );
}

/**
 * Shortcode to show the Giveaway
 *
 * @param array $atts
 *
 * @return string
 */
function giveasap_shortcode( $atts ) {

	 $attributes = shortcode_atts( array(
         'id' => '0',
         'description' => '',
         'title' => '1',
         'redirect' => 'self',
         'images' => '0',
         'use_link' => '1',
         'prizes'   => '1',
         'show_form' => '1',
         'only_form' => '0',
     ), $atts );

	if( $attributes['id'] == '0' ) {
		return '';
	}

	$post           = get_post( $attributes['id'] );
	$giveaway       = sg_get_giveaway( $post );
	$prize          = $giveaway->get_prize_settings();
	$display        = false;
	$gasap          = gasap();
 	$giveasap_front = new GiveASAP_Front( $post );
 	$giveasap_ended = false;

	if ( absint( $attributes['images'] ) === 1 ) {
		$display = $giveaway->get_display_settings();
	}

	if( $giveaway->has_ended() ) {
		$giveasap_ended = true;
	} 

	$timezone          = get_option('gmt_offset');
 	$giveasap_settings = giveasap_get_settings();
 	$current_page_url  = sg_get_current_page_url();

 	if ( 'giveaway' !== $attributes['redirect'] ) {
	    if ( 'self' === $attributes['redirect'] ) {
		    $giveasap_front->set_from_page( $current_page_url );
	    } elseif ( strpos( $attributes['redirect'], 'http' ) !== false ) {
		    $giveasap_front->set_from_page( $attributes['redirect'] );
	    }
    }


    $giveasap_front->set_share_url( $current_page_url );

 	$output = '';
 	ob_start();
	$gasap->load_scripts( $giveasap_front );

 	?>
	<div class="giveasap-box sg-shortcode">

		<?php
        if ( '1' !== $attributes['only_form'] ) {
	        if ( ( isset( $prize['winners'] ) && $prize['winners'] )
	             || ( isset( $prize['value'] ) && $prize['value'] )
	             || ( isset( $prize['prize'] ) && $prize['prize'] )
	        ) {
		        ?>
                <ul class="sg-meta sg-meta-prizes">
			        <?php
			        if ( isset( $prize['winners'] ) && $prize['winners'] ) {
				        ?>
                        <li class="person">
                            <span class="fal fa-user-times"></span>
					        <?php echo sprintf( _n( '%s <small>winner</small>', '%s <small>winners</small>', $prize["winners"], 'giveasap' ), number_format_i18n( $prize["winners"] ) ); ?>
                        </li>
			        <?php } ?>
			        <?php
			        if ( isset( $prize['value'] ) && $prize['value'] ) {
				        ?>
                        <li class="value">
                            <span class="fal fa-money-bill"></span>
                            <small><?php _e( 'Value:', 'giveasap' ); ?></small>
					        <?php echo $prize["value"]; ?>
                        </li>
			        <?php } ?>
			        <?php
			        if ( isset( $prize['prize'] ) && $prize['prize'] ) {
				        ?>
                        <li class="value">
                            <span class="fal fa-gift"></span>
                            <small><?php _e( 'Prize:', 'giveasap' ); ?></small>
					        <?php echo $prize["prize"]; ?>
                        </li>
			        <?php } ?>
                </ul>
		        <?php
	        }

	        if ( '1' === $attributes['title'] ) {
		        echo '<h2 class="sg-title">';

		        if ( '1' === $attributes['use_link'] ) {
			        echo '<a href="' . $giveasap_front->get_form_link() . '">';
		        }

		        echo $post->post_title;

		        if ( '1' === $attributes['use_link'] ) {
			        echo '</a>';
		        }
		        echo '</h2>';
	        }

	        if ( '' !== $attributes['description'] ) {
		        echo '<p>' . apply_filters( 'giveasap_shortcode_description', $attributes['description'] ) . '</p>';
	        }

	        if ( '0' !== $attributes['prizes'] ) {
		        sg_header_show_prizes( $giveaway );
	        }

	        if ( $display ) {
		        the_giveasap_gallery( $display['images'] );
	        }
        }

 	if( ! $giveasap_ended ) {

        if ( '1' !== $attributes['only_form'] ) {
	        ?>
            <div data-timezone="<?php echo $timezone; ?>"
                 data-end="<?php echo giveasap_get_end_time( $giveaway->get_id() ); ?>" class="giveasap_countdown">

            </div>
            <?php
            if ( $giveasap_front->get_step() == 1 ) {

                if ( $giveasap_settings['google_site_key'] ) { ?>
                    <script src='https://www.google.com/recaptcha/api.js'></script>
                <?php
                }
            } else {
            ?>
            <h3 class="sg-participation-message"><?php _e( 'You are participating in this giveaway', 'giveasap' ); ?></h3>
            <?php
            }
        }

        if ( '0' !== $attributes['show_form'] ) {

	        giveasap_the_form( $giveasap_front, $giveasap_settings );
        }
		?>

	<?php } else { ?>
		<div class="giveasap_alert giveasap_ended">
			<?php _e( 'Ended', 'giveasap' ); ?>
		</div>
	<?php
		giveasap_show_winners( $giveaway->get_id() );

 	    }
 	?>
    </div>

    <script type="text/javascript">
        if( typeof giveasap_shortcode_loaded === 'undefined' ) {
            giveasap_shortcode_loaded = false;
        }

        if( ! giveasap_shortcode_loaded ) {
            var link = document.createElement( "link" );
            link.href = '<?php echo GASAP_URI; ?>assets/dist/css/shortcode.css';
            link.type = "text/css";
            link.rel = "stylesheet";
            link.media = "all";

            document.getElementsByTagName( "head" )[0].appendChild( link );
            giveasap_shortcode_loaded = true;
        }
    </script>
<?php

	$output = ob_get_clean();
	return $output;
}

/**
 * Show the winners in a shortcode.
 *
 * @since 2.17.0
 *
 * @param array $atts Shortcode Attributes.
 * @return string
 */
function sg_show_winners_shortcode( $atts ) {
	$attributes = shortcode_atts( array(
		'id' => 0
	), $atts );

	if ( ! absint( $attributes['id'] ) ) {
	    return '';
    }

    ob_start();
	giveasap_show_winners( absint( $attributes['id'] ), true );
    return ob_get_clean();
}


/**
 * Display Leaderboard
 *
 * @param array $atts
 *
 * @return string
 */
function sg_giveaway_leaderboard_shortcode( $atts ) {
	$atts = shortcode_atts( array(
		'id' => '',
		'limit' => 10,
		'order' => 'DESC',
		'orderby' => 'entries',
		'columns' => 'entries,email',
		'headers' => 'Entries,Email'
	), $atts);

	if ( ! $atts['id'] || absint( $atts['id'] ) <= 0 ) {
		return '';
	}

	$results = get_transient( 'giveaway_leaderboard_' . $atts['id'] );

	if ( false === $results ) {
		$results = giveasap_get_active_entries_for( $atts['id'], $atts['limit'], $atts['order'], $atts['orderby'] );
		$_results = array_map( 'json_encode', $results );
        $results  = array();
        foreach ( $_results as $index => $result ) {
            $results[ $index ] = json_decode( $result, true );
        }
		if ( ! $results ) {
			return '';
		}

		foreach ( $results as $index => $result ) {
			$results[ $index ]['meta'] = get_metadata( 'giveasap', $result['id'] );
		}

		set_transient( 'giveaway_leaderboard_' . $atts['id'], $results, 12 * HOUR_IN_SECONDS );
	}

	$columns = explode( ',', $atts['columns'] );
	$headers = explode( ',', $atts['headers'] );
	if ( count( $headers ) !== count( $columns ) ) {
		$headers = array();
		foreach ( $columns as $column ) {
			$headers[] = $column;
		}
	}

	ob_start();
	?>

    <table class="giveaway-leaderboard">
        <thead>
        <tr>
            <th>#</th>
			<?php
			foreach ( $headers as $header ) {
				echo '<th>' . $header . '</th>';
			}
			?>
        </tr>
        </thead>
        <tbody>
		<?php
		foreach ( $results as $index => $result ) {
		    if ( $index >= $atts['limit'] ) {
		        break;
            }
			?>
            <tr>
                <td><?php echo $index + 1; ?></td>
				<?php
				foreach ( $columns as $column ) {
					echo '<td>';
					if ( isset( $result[ $column ] ) ) {
					    if ( 'email' === $column ) {
						    echo sg_mask_email( $result[ $column ] );
                        } else {
						    echo $result[ $column ];
					    }
					} elseif ( isset( $result['meta'][ $column ] ) ) {
						echo $result['meta'][ $column ][0];
					} elseif ( isset( $result['meta'][ '_' . $column ] ) ) {
						echo $result['meta'][ '_' . $column ][0];
					} else {
						echo '-';
					}
					echo '</td>';
				}
				?>
            </tr>
			<?php
		}
		?>
        </tbody>
    </table>
    <script type="text/javascript">
        if( typeof giveasap_shortcode_loaded === 'undefined' ) {
            giveasap_shortcode_loaded = false;
        }

        if( ! giveasap_shortcode_loaded ) {
            var link = document.createElement( "link" );
            link.href = '<?php echo GASAP_URI; ?>assets/dist/css/shortcode.css';
            link.type = "text/css";
            link.rel = "stylesheet";
            link.media = "all";

            document.getElementsByTagName( "head" )[0].appendChild( link );
            giveasap_shortcode_loaded = true;
        }
    </script>
	<?php

	return ob_get_clean();
}
